<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="61"/>
        <source>:/txt/authors_en.txt</source>
        <translation>:/txt/authors_en.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>:/txt/thanks_en.txt</source>
        <translation>:/txt/thanks_en.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>:/txt/translators_en.txt</source>
        <translation>:/txt/translators_en.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt alapú Multimédia Lejátszó (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Version:</source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>:txt/description_en.txt</source>
        <translation>:txt/description_en.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Input plugins:</source>
        <translation>Bemeneti pluginek:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Output plugins:</source>
        <translation>Kimeneti pluginek:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>Visual plugins:</source>
        <translation>Vizuális pluginek:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="111"/>
        <source>Effect plugins:</source>
        <translation>Effekt pluginek:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>Általános pluginek:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>Névjegy: Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="40"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="54"/>
        <source>Authors</source>
        <translation>Készítők</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="68"/>
        <source>Translators</source>
        <translation>Fordítók</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="82"/>
        <source>Thanks To</source>
        <translation>Köszönet</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="96"/>
        <source>License Agreement</source>
        <translation>Licensz Egyezmény</translation>
    </message>
</context>
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>&amp;Play</source>
        <translation type="unfinished">&amp;Lejátszás</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Pause</source>
        <translation type="unfinished">&amp;Szünet</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>C</source>
        <translation type="unfinished">C</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Stop</source>
        <translation type="unfinished">&amp;Megállítás</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>V</source>
        <translation type="unfinished">V</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Previous</source>
        <translation type="unfinished">&amp;Előző</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>Z</source>
        <translation type="unfinished">Z</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Next</source>
        <translation type="unfinished">&amp;Következő</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>B</source>
        <translation type="unfinished">B</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Play/Pause</source>
        <translation type="unfinished">&amp;Lejátszás/Szünet</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>Space</source>
        <translation type="unfinished">Szóköz</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Jump to File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>J</source>
        <translation type="unfinished">J</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Repeat Playlist</source>
        <translation type="unfinished">Lista &amp;ismétlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Track</source>
        <translation type="unfinished">Számok i&amp;smétlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>Ctrl+R</source>
        <translation type="unfinished">Crtl+R</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Shuffle</source>
        <translation type="unfinished">&amp;Véletlenszerű</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>S</source>
        <translation type="unfinished">S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;No Playlist Advance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>&amp;Stop After Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>&amp;Clear Queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Alt+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Show Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Equalizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Always on Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Put on All Workspaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Double Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>&amp;Add File</source>
        <translation type="unfinished">&amp;Fájl hozzáadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>F</source>
        <translation type="unfinished">F</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add Directory</source>
        <translation type="unfinished">&amp;Könyvtár hazááadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>D</source>
        <translation type="unfinished">D</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Url</source>
        <translation type="unfinished">&amp;Url hozzáadása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>U</source>
        <translation type="unfinished">U</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Remove Selected</source>
        <translation type="unfinished">&amp;Megjelöltek eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>Del</source>
        <translation type="unfinished">Del</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>&amp;Remove All</source>
        <translation type="unfinished">&amp;Összes eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove Unselected</source>
        <translation type="unfinished">&amp;Jelöletlenek eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="67"/>
        <source>Remove unavailable files</source>
        <translation type="unfinished">Elérhetetlen fájlok eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="69"/>
        <source>Remove duplicates</source>
        <translation type="unfinished">Duplikációk eltávolítása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>&amp;Queue Toggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Q</source>
        <translation type="unfinished">Q</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Invert Selection</source>
        <translation type="unfinished">Fordított kijelölés</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>&amp;Select None</source>
        <translation type="unfinished">&amp;Kijelölés megszűntetése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select All</source>
        <translation type="unfinished">&amp;Összes kijelölése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Ctrl+A</source>
        <translation type="unfinished">Ctrl+A</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>&amp;View Track Details</source>
        <translation type="unfinished">Szám adatainak &amp;megnézése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Alt+I</source>
        <translation type="unfinished">Alt+I</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>&amp;New List</source>
        <translation type="unfinished">&amp;Új lista</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Ctrl+T</source>
        <translation type="unfinished">Ctrl+T</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;Delete List</source>
        <translation type="unfinished">&amp;Lista törlése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+W</source>
        <translation type="unfinished">Ctrl+W</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Load List</source>
        <translation type="unfinished">&amp;Lista betöltése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>O</source>
        <translation type="unfinished">O</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Save List</source>
        <translation type="unfinished">Lista &amp;mentése</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Shift+S</source>
        <translation type="unfinished">Shift+S</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Select Next Playlist</source>
        <translation type="unfinished">&amp;Következő lista választása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished">Ctrl+PgDown</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>&amp;Select Previous Playlist</source>
        <translation type="unfinished">&amp;Előző lista választása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished">Ctrl+PgUp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Show Playlists</source>
        <translation type="unfinished">&amp;Lejátszási lista mutatása</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>P</source>
        <translation type="unfinished">P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Beállítások</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Ctrl+P</source>
        <translation type="unfinished">Ctrl+P</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;About</source>
        <translation type="unfinished">&amp;Névjegy</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About Qt</source>
        <translation type="unfinished">N&amp;évjegy: Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Exit</source>
        <translation type="unfinished">&amp;Kilépés</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished">Ctrl+Q</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../addurldialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="13"/>
        <source>Enter URL to add</source>
        <translation>Írj be egy URL-t a hozzáadáshoz</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="51"/>
        <source>&amp;Add</source>
        <translation>&amp;Hozzáad</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="58"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégsem</translation>
    </message>
</context>
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Don&apos;t clear the playlist</source>
        <translation type="unfinished">Ne töröld a lejátszási listát</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Start playing current song</source>
        <translation>Aktuális szám lejátszásának indítása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Pause current song</source>
        <translation>Aktuális szám szüneteltetése</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Szünet ha lejátszás van, különben lejátszás</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Stop current song</source>
        <translation>Aktuális szám megállítása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Display Jump to File dialog</source>
        <translation>Számra ugrás ablak mutatása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Lejátszási hangerő beállítása (pl.: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Skip forward in playlist</source>
        <translation>Lejátszási lista következő számának kihagyása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Skip backwards in playlist</source>
        <translation>Lejátszási lista előző számainak kihagyása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Show/hide application</source>
        <translation>Alkalmazás mutatása/elrejtése</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Display Add File dialog</source>
        <translation>Fájl hozzáadása ablak mutatása</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Add Directory dialog</source>
        <translation>Könyvtár hozzáadása ablak mutatása</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.cpp" line="209"/>
        <source>Archived skin</source>
        <translation>Tömörített skin</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="231"/>
        <source>Unarchived skin</source>
        <translation>Tömörítettlen skin</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="735"/>
        <source>Description</source>
        <translation>Leírás</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="740"/>
        <source>Filename</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="429"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <location filename="../configdialog.cpp" line="430"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="431"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="434"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="440"/>
        <source>Year</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="435"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Track</source>
        <translation>Szám</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>Disabled</source>
        <translation>Kikapcsolva</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>Transports</source>
        <translation>Transzportálás</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="255"/>
        <source>Decoders</source>
        <translation>Dekóderek</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="265"/>
        <source>Engines</source>
        <translation>Motorok</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="432"/>
        <source>Track number</source>
        <translation>Zeneszám</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="433"/>
        <source>Two-digit track number</source>
        <translation>Két jegyű zeneszám</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="436"/>
        <source>Composer</source>
        <translation>Zeneszerző</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="437"/>
        <source>Disc number</source>
        <translation>Lemezszám</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="438"/>
        <source>File name</source>
        <translation>Fájl neve</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="439"/>
        <source>File path</source>
        <translation>File útvonala</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="441"/>
        <source>Condition</source>
        <translation>Feltétel</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="524"/>
        <source>Select Skin Files</source>
        <translation>Skin fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="525"/>
        <source>Skin files</source>
        <translation>Skin fájlok</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Qmmp beállítások</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="98"/>
        <source>Appearance</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="107"/>
        <location filename="../forms/configdialog.ui" line="463"/>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Playlist</source>
        <translation>Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="116"/>
        <source>Plugins</source>
        <translation>Beépülők</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="125"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="134"/>
        <source>Connectivity</source>
        <translation>Összekapcsolhatóság</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="184"/>
        <source>Skins</source>
        <translation>Skinek</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Add...</source>
        <translation>Hozzáad...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="228"/>
        <source>Refresh</source>
        <translation>Frissít</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="249"/>
        <source>Miscellaneous</source>
        <translation>Vegyes</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="291"/>
        <source>Fonts</source>
        <translation>Betűtípus</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="309"/>
        <source>Player:</source>
        <translation>Lejátszó:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <location filename="../forms/configdialog.ui" line="386"/>
        <location filename="../forms/configdialog.ui" line="552"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="357"/>
        <source>Playlist:</source>
        <translation>Lejátszási lista:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Use bitmap font if available</source>
        <translation>Bittérképes betűtípus használata, ha elérhető</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="275"/>
        <source>Use skin cursors</source>
        <translation>Skin egértéma használata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="152"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Metadata</source>
        <translation>Metaadatok</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="523"/>
        <source>Load metadata from files</source>
        <translation>Metaadatok betöltése fájlból</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="533"/>
        <source>Song Display</source>
        <translation>Szám kijelző</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="539"/>
        <source>Title format:</source>
        <translation>Cím formátum:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="559"/>
        <source>Convert underscores to blanks</source>
        <translation>Lepontozottak átalakítása üressé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="566"/>
        <source>Convert %20 to blanks</source>
        <translation>Átalakítás %20 üressé</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>Show protocol</source>
        <translation>Protokol mutatása</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="580"/>
        <source>Show song numbers</source>
        <translation>Zene sorszámának mutatása</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="587"/>
        <source>Show playlists</source>
        <translation>Lejátszási lista mutatása</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="596"/>
        <source>Show popup information</source>
        <translation>Felugró információk mutatása</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Show anchor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="638"/>
        <source>Align song numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="686"/>
        <location filename="../forms/configdialog.ui" line="1153"/>
        <source>Preferences</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="699"/>
        <location filename="../forms/configdialog.ui" line="761"/>
        <location filename="../forms/configdialog.ui" line="1166"/>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Playback</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="873"/>
        <source>Continue playback on startup</source>
        <translation>Lejátszás folytatása indításkor</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1189"/>
        <source>Buffer size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1202"/>
        <source>ms</source>
        <translation type="unfinished">ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1238"/>
        <source>16-bit output</source>
        <translation>16 bites kimenet</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1272"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1277"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1285"/>
        <source>Change shortcut...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>Visualization</source>
        <translation>Vizualizáció</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="275"/>
        <source>Effects</source>
        <translation>Effektek</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <location filename="../forms/configdialog.ui" line="1131"/>
        <source>Audio</source>
        <translation>Audió</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1001"/>
        <source>Replay Gain</source>
        <translation>Replay Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1007"/>
        <source>Replay Gain mode:</source>
        <translation>Replay Gain mód:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1024"/>
        <source>Preamp:</source>
        <translation>Preamp:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1056"/>
        <location filename="../forms/configdialog.ui" line="1101"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1069"/>
        <source>Default gain:</source>
        <translation>Alapértelmezett gain:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Csúcs információ használata a klippelés megelőzéséhez</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1137"/>
        <source>Output:</source>
        <translation>Kimenet:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1231"/>
        <source>Use software volume control</source>
        <translation>Szoftveres hangerőszabályzó használata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="261"/>
        <source>Hide on close</source>
        <translation>Elrejtés bezáráskor</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="268"/>
        <source>Start hidden</source>
        <translation>Rejtve induljon</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="752"/>
        <source>File Dialog</source>
        <translation>Fájl ablak</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="403"/>
        <source>Transparency</source>
        <translation>Átlátszóság</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="255"/>
        <location filename="../configdialog.cpp" line="360"/>
        <source>View</source>
        <translation>Megnéz</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="409"/>
        <source>Main window</source>
        <translation>Fő ablak</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="432"/>
        <location filename="../forms/configdialog.ui" line="456"/>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="439"/>
        <source>Equalizer</source>
        <translation>Hangszínszabályozó</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="606"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="784"/>
        <source>Cover Image Retrieve</source>
        <translation>Borító beszerzése</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="790"/>
        <source>Use separate image files</source>
        <translation>Különböző képfájlok használata</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="800"/>
        <source>Include files:</source>
        <translation>Tartalmazott fájlok:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="810"/>
        <source>Exclude files:</source>
        <translation>Kihagyott fájlok:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Recursive search depth:</source>
        <translation>Rekúrzív keresési mélység:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="899"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="911"/>
        <source>Enable proxy usage</source>
        <translation>Proxy használatának engedélyezése</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="918"/>
        <source>Proxy host name:</source>
        <translation>Proxy host name:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="931"/>
        <source>Proxy port:</source>
        <translation>Proxy port:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="944"/>
        <source>Use authentication with proxy</source>
        <translation>Hitelesítés hasznáalta proxy-val</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="951"/>
        <source>Proxy user name:</source>
        <translation>Proxy felhasználónév:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="964"/>
        <source>Proxy password:</source>
        <translation>Proxy jelszó:</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="43"/>
        <source>Equalizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="154"/>
        <location filename="../eqwidget.cpp" line="177"/>
        <source>preset</source>
        <translation>beállítás</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="261"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Betölt/Töröl</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="263"/>
        <source>&amp;Save Preset</source>
        <translation>Beálítás  &amp;mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="265"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>&amp;Automatikusan betöltödő beállítás mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="267"/>
        <source>&amp;Import</source>
        <translation>&amp;Importálás</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Clear</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="299"/>
        <source>Saving Preset</source>
        <translation>Beállítások mentése</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="300"/>
        <source>Preset name:</source>
        <translation>Beállítás neve:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="301"/>
        <source>preset #</source>
        <translation>beállítás #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="392"/>
        <source>Import Preset</source>
        <translation>Beállítás importálása</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Ugrás számra</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="86"/>
        <location filename="../jumptotrackdialog.cpp" line="137"/>
        <source>Queue</source>
        <translation>Sorba betesz</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Frissít</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Ugrás</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="53"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="54"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="55"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="84"/>
        <location filename="../jumptotrackdialog.cpp" line="135"/>
        <source>Unqueue</source>
        <translation>Sorból kivesz</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Megállít</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Fájl hozzáadása</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Hangszínszabályzó</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Lista ismétlése</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Véletlenszerű</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Hangerő</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Egyensúly</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="280"/>
        <source>Visualization Mode</source>
        <translation>Vizualizációs mód</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>Analyzer</source>
        <translation>Analyzer</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>Scope</source>
        <translation>Scope</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Mode</source>
        <translation>Analyzer mód</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <source>Normal</source>
        <translation>Hagyományos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <source>Fire</source>
        <translation>Tűz</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <source>Vertical Lines</source>
        <translation>Függőleges vonalak</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <source>Lines</source>
        <translation>Vonalak</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <source>Bars</source>
        <translation>Csíkok</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Csúcsok</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="316"/>
        <source>Refresh Rate</source>
        <translation>Ráta frissítése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>25 fps</source>
        <translation>25 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="321"/>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="322"/>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="329"/>
        <source>Analyzer Falloff</source>
        <translation>Analízer esése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="332"/>
        <location filename="../mainvisual.cpp" line="346"/>
        <source>Slowest</source>
        <translation>Lassabb</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="333"/>
        <location filename="../mainvisual.cpp" line="347"/>
        <source>Slow</source>
        <translation>Lassú</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="334"/>
        <location filename="../mainvisual.cpp" line="348"/>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="335"/>
        <location filename="../mainvisual.cpp" line="349"/>
        <source>Fast</source>
        <translation>Gyors</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="336"/>
        <location filename="../mainvisual.cpp" line="350"/>
        <source>Fastest</source>
        <translation>Gyorsabb</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="343"/>
        <source>Peaks Falloff</source>
        <translation>Csúcsok esése</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="356"/>
        <source>Background</source>
        <translation>Háttér</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="357"/>
        <source>Transparent</source>
        <translation>Átlátszóság</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Choose a directory</source>
        <translation>Válassz egy könyvtárat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>All Supported Bitstreams</source>
        <translation>Minden támogatott bitráta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Select one or more files to open</source>
        <translation>Válassz egy vagy több fájlat megnyitásra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>View</source>
        <translation type="unfinished">Megnéz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Tools</source>
        <translation>Eszközök</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Playlist Files</source>
        <translation>Lejátszási lista fájl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Open Playlist</source>
        <translation>Lista megnyitása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Save Playlist</source>
        <translation>Lista mentése</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation type="unfinished">Lejátszási lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="204"/>
        <source>Sort List</source>
        <translation>Lista rendezése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <location filename="../playlist.cpp" line="242"/>
        <source>By Title</source>
        <translation>Cím szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="211"/>
        <location filename="../playlist.cpp" line="246"/>
        <source>By Album</source>
        <translation>Album szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="215"/>
        <location filename="../playlist.cpp" line="250"/>
        <source>By Artist</source>
        <translation>Előadó szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="219"/>
        <location filename="../playlist.cpp" line="254"/>
        <source>By Filename</source>
        <translation>Fájlnév szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="223"/>
        <location filename="../playlist.cpp" line="258"/>
        <source>By Path + Filename</source>
        <translation>Elérési út és fájlnév szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="227"/>
        <location filename="../playlist.cpp" line="262"/>
        <source>By Date</source>
        <translation>Dátum szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="231"/>
        <location filename="../playlist.cpp" line="266"/>
        <source>By Track Number</source>
        <translation>Zene sorszáma szerint</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="239"/>
        <source>Sort Selection</source>
        <translation>Jelöltek rendezése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="274"/>
        <source>Randomize List</source>
        <translation>Lista összekeverése</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="276"/>
        <source>Reverse List</source>
        <translation>Fordított lista</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="283"/>
        <source>Actions</source>
        <translation>Tevékenységek</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="550"/>
        <source>&amp;New PlayList</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="177"/>
        <source>&amp;Copy Selection To</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Lejátszási lista böngésző</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="38"/>
        <source>Rename</source>
        <translation>Átnevez</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Load</source>
        <translation>&amp;Betölt</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="52"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Mentés másként...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>Rename</source>
        <translation>Átnevez</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="55"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Rename Playlist</source>
        <translation>Lista átnevezése</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Playlist name:</source>
        <translation>Lista neve:</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Popup Információs Beállítások</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Borító mutatása</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Átlátszóság:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Borító mérete:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Sablon</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Visszaállít</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Beszúr</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Előadó</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Cím</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Zeneszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Két jegyű zeneszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Műfaj</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Megjegyzés</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Szerző</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Lemezszám</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Fájl neve</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Fájl útvonala</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Év</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Feltétel</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Beállítás szerkesztő</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Betölt</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Töröl</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Automatikus beállítás</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="71"/>
        <source>Unknown command</source>
        <translation>Ismeretlen parancs</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="176"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Használat: qmmp [opciók] [fájlok]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="177"/>
        <source>Options:</source>
        <translation>Opciók:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="181"/>
        <source>Don&apos;t start the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="182"/>
        <source>Display this text and exit</source>
        <translation>Mutasd ezt a szöveget, majd lépj ki</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="183"/>
        <source>Print version number and exit</source>
        <translation>Mutasd a verziószámot, majd lépj ki</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="184"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Ötleteket, foltokat, hibajelentéseket küld a forkotov02@hotmail.ru címre</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="189"/>
        <source>QMMP version:</source>
        <translation>QMMP verzió:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="190"/>
        <source>Qt version:</source>
        <translation>Qt verzió:</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="43"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Számok címének görgetése</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="118"/>
        <source>Buffering: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="29"/>
        <source>Visualization</source>
        <translation>Vizualizáció</translation>
    </message>
</context>
</TS>
